summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/kopeteapplication.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/kopeteapplication.cpp')
-rw-r--r--kopete/kopete/kopeteapplication.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/kopete/kopeteapplication.cpp b/kopete/kopete/kopeteapplication.cpp
index 2e469bf5..5b07089f 100644
--- a/kopete/kopete/kopeteapplication.cpp
+++ b/kopete/kopete/kopeteapplication.cpp
@@ -72,7 +72,7 @@ KopeteApplication::KopeteApplication()
* TQApplication thinks the application shuts down (this is usually the case
* when the loop_level goes down to zero) . So it emits aboutToQuit(), to
* which TDEApplication is connected and re-emits shutdown() , to which again
* KMainWindow (a KopeteWindow instance exists already) is connected. KMainWindow's
* shuttingDown() slot calls queryExit() which results in KopeteWindow::queryExit()
* calling unloadPlugins() . This of course is wrong and just shouldn't happen.
* The workaround is to simply delay the initialization of all this to a point
@@ -316,7 +316,7 @@ void KopeteApplication::quitKopete()
m_isShuttingDown = true;
// close all windows
- TQPtrListIterator<KMainWindow> it(*KMainWindow::memberList);
+ TQPtrListIterator<TDEMainWindow> it(*TDEMainWindow::memberList);
for (it.toFirst(); it.current(); ++it)
{
if ( !it.current()->close() )
@@ -72,7 +72,7 @@ KopeteApplication::KopeteApplication()
* when the loop_level goes down to zero) . So it emits aboutToQuit(), to
* which TDEApplication is connected and re-emits shutdown() , to which again
- * KMainWindow (a KopeteWindow instance exists already) is connected. KMainWindow's
+ * TDEMainWindow (a KopeteWindow instance exists already) is connected. TDEMainWindow's
* shuttingDown() slot calls queryExit() which results in KopeteWindow::queryExit()
* calling unloadPlugins() . This of course is wrong and just shouldn't happen.